﻿using System;
using System.Collections.Generic;
using System.Linq;
using RdvMedecins.Entites;
using RdvMedecins.Exceptions;
using RdvMedecins.Models;
using System.Data;

namespace RdvMedecins.Dao
{
  public class Dao : IDao
  {

    //liste des clients
    public List<Client> GetAllClients()
    {
      // liste des clients
      List<Client> clients = null;
      try
      {
        // ouverture contexte de persistance
        using (var context = new RdvMedecinsContext())
        {
          // liste des clients
          clients = context.Clients.ToList<Client>();
        }

      }
      catch (Exception ex)
      {
        throw new RdvMedecinsException(1, "GetAllClients", ex);
      }
      // on rend le résultat
      return clients;
    }

    // liste des médecins
    public List<Medecin> GetAllMedecins()
    {
      // liste des médecins
      List<Medecin> medecins = null;
      try
      {
        // ouverture contexte de persistance
        using (var context = new RdvMedecinsContext())
        {
          // liste des médecins
          medecins = context.Medecins.ToList<Medecin>();
        }

      }
      catch (Exception ex)
      {
        throw new RdvMedecinsException(2, "GetAllMedecins", ex);
      }
      // on rend le résultat
      return medecins;
    }

    // liste des créneaux horaires d'un médecin donné
    public List<Creneau> GetCreneauxMedecin(int idMedecin)
    {
      // liste des créneaux
      try
      {
        // ouverture contexte de persistance
        using (var context = new RdvMedecinsContext())
        {
          // on récupère le médecin avec ses créneaux
          Medecin medecin = context.Medecins.Include("Creneaux").Single(m => m.Id == idMedecin);
          // on retourne la liste des créneaux du médecin
          return medecin.Creneaux.ToList<Creneau>();
        }
      }
      catch (Exception ex)
      {
        throw new RdvMedecinsException(3, "GetCreneauxMedecin", ex);
      }
    }

    // liste des RV d'un médecin pour un jour donné
    public List<Rv> GetRvMedecinJour(int idMedecin, DateTime jour)
    {
      // liste des Rv
      List<Rv> rvs = null;

      try
      {
        // ouverture contexte de persistance
        using (var context = new RdvMedecinsContext())
        {
          // on récupère le médecin
          Medecin medecin = context.Medecins.Find(idMedecin);
          if (medecin == null)
          {
            throw new RdvMedecinsException(10, string.Format("Médecin [{0}] inexistant", idMedecin));
          }
          // liste des rv
          rvs = context.Rvs.Where(r => r.Creneau.Medecin.Id == idMedecin && r.Jour == jour).ToList();
        }
      }
      catch (Exception ex)
      {
        throw new RdvMedecinsException(4, "GetRvMedecinJour", ex);
      }
      // on rend le résultat
      return rvs;
    }

    // ajouter un RV
    public int AjouterRv(DateTime jour, int idCreneau, int idClient)
    {
      // n° du Rdv ajouté
      int idRv;
      try
      {
        // ouverture contexte de persistance
        using (var context = new RdvMedecinsContext())
        {
          // on récupère le créneau
          Creneau creneau = context.Creneaux.Find(idCreneau);
          if (creneau == null)
          {
            throw new RdvMedecinsException(5, string.Format("Créneau [{0}] inexistant", idCreneau));
          }
          // on récupère le client
          Client client = context.Clients.Find(idClient);
          if (client == null)
          {
            throw new RdvMedecinsException(6, string.Format("Client [{0}] inexistant", idCreneau));
          }
          // création créneau
          Rv rv = new Rv { Jour = jour, Client = client, Creneau = creneau };
          // ajout dans le contexte
          context.Rvs.Add(rv);
          // sauvegarde du contexte
          context.SaveChanges();
          // on récupère la clé primaire du rv ajouté
          idRv = (int)rv.Id;
        }
      }
      catch (Exception ex)
      {
        throw new RdvMedecinsException(7, "AjouterRv", ex);
      }
      // résultat
      return idRv;
    }

    // supprimer un RV
    public void SupprimerRv(int idRv)
    {
      try
      {
        // ouverture contexte de persistance
        using (var context = new RdvMedecinsContext())
        {
          // on récupère le Rv
          Rv rv = context.Rvs.Find(idRv);
          if (rv == null)
          {
            throw new RdvMedecinsException(5, string.Format("Rv [{0}] inexistant", idRv));
          }
          // suppression Rv
          context.Rvs.Remove(rv);
          // sauvegarde du contexte
          context.SaveChanges();
        }
      }
      catch (Exception ex)
      {
        throw new RdvMedecinsException(8, "SupprimerRv", ex);
      }
    }

    // trouver une entité à partir de sa clé primaire
    public T Find<T>(int id)  where T : class
    {
      try
      {
        // ouverture contexte de persistance
        using (var context = new RdvMedecinsContext())
        {
          return context.Set<T>().Find(id);
        }
      }
      catch (Exception ex)
      {
        throw new RdvMedecinsException(20, "Find<T>", ex);
      }
    }
  }
}
