﻿using System;
using System.Data;
using RdvMedecins.Entites;
using RdvMedecins.Models;

namespace RdvMedecins_01
{
  class ModifyDetachedEntities
  {
    static void Main(string[] args)
    {
      Client client1;

      // on vide la base actuelle
      Erase();
      // on ajoute un client
      using (var context = new RdvMedecinsContext())
      {
        // création client
        client1 = new Client { Titre = "x", Nom = "x", Prenom = "x" };
        // ajout du client au contexte
        context.Clients.Add(client1);
        // on sauvegarde le contexte
        context.SaveChanges();
      }
      // affichage base
      Dump("1-----------------------------");
      // on récupère client1 pour avoir sa version
      using (var context = new RdvMedecinsContext())
      {
        // client2 sera dans le contexte
        Client client2 = context.Clients.Find(client1.Id);
        // on fixe la version de client1 à celle de client2
        client1.Versioning = client2.Versioning;
      }
      // client1 n'est pas dans le contexte - on le modifie
      client1.Nom = "y";
      // modification entité hors contexte
      using (var context = new RdvMedecinsContext())
      {
        // ici, on a un nouveau contexte vide
        // on met client1 dans le contexte dans un état modifié
        context.Entry(client1).State = EntityState.Modified;
        // on sauvegarde le contexte
        context.SaveChanges();
      }
      // affichage base
      Dump("2-----------------------------");
      // suppression entité hors contexte
      using (var context = new RdvMedecinsContext())
      {
        // ici, on a un nouveau contexte vide
        // on met client1 dans le contexte dans un état supprimé
        context.Entry(client1).State = EntityState.Deleted;
        // on sauvegarde le contexte
        context.SaveChanges();
      }
      // affichage base
      Dump("3-----------------------------");
    }

    static void Erase()
    {
      // vide la base
      using (var context = new RdvMedecinsContext())
      {
        foreach (var client in context.Clients)
        {
          context.Clients.Remove(client);
        }
        foreach (var medecin in context.Medecins)
        {
          context.Medecins.Remove(medecin);
        }
        // on sauvegarde le contexte
        context.SaveChanges();
      }
    }

    static void Dump(string str)
    {
      Console.WriteLine(str);
      // affiche la base
      using (var context = new RdvMedecinsContext())
      {
        foreach (var rv in context.Rvs)
        {
          Console.WriteLine(rv);
        }
        foreach (var creneau in context.Creneaux)
        {
          Console.WriteLine(creneau);
        }
        foreach (var client in context.Clients)
        {
          Console.WriteLine(client);
        }
        foreach (var medecin in context.Medecins)
        {
          Console.WriteLine(medecin);
        }
      }
    }
  }
}
