﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;

namespace RdvMedecins.Entites
{
  // une personne
  public abstract class Personne
  {
    // data
    [Key]
    [Column("ID")]
    public int? Id { get; set; }
    [Required]
    [MaxLength(5)]
    [Column("TITRE")]
    public string Titre { get; set; }
    [Required]
    [MaxLength(30)]
    [Column("NOM")]
    public string Nom { get; set; }
    [Required]
    [MaxLength(30)]
    [Column("PRENOM")]
    public string Prenom { get; set; }
    [ConcurrencyCheck]
    [Column("VERSIONING")]
    public int? Versioning { get; set; }

    // signature
    public override string ToString()
    {
      return String.Format("[{0},{1},{2},{3},{4}]", Id, Titre, Prenom, Nom, Versioning);
    }
    // signature courte
    public string ShortIdentity()
    {
      return ToString();
    }
  }

  [Table("MEDECINS", Schema = "RDVMEDECINS-EF")]
  public class Medecin : Personne
  {
    // les créneaux horaires du médecin
    public ICollection<Creneau> Creneaux { get; set; }
    // signature
    public override string ToString()
    {
      return String.Format("Medecin {0}", base.ToString());
    }
  }

  [Table("CLIENTS", Schema = "RDVMEDECINS-EF")]
  public class Client : Personne
  {
    // les Rvs du client
    public ICollection<Rv> Rvs { get; set; }
    // signature
    public override string ToString()
    {
      return String.Format("Client {0}", base.ToString());
    }
  }

  // un créneau horaire
  [Table("CRENEAUX", Schema = "RDVMEDECINS-EF")]
  public class Creneau
  {
    // data
    [Key]
    [Column("ID")]
    public int? Id { get; set; }
    [Required]
    [Column("HDEBUT")]
    public int Hdebut { get; set; }
    [Required]
    [Column("MDEBUT")]
    public int Mdebut { get; set; }
    [Required]
    [Column("HFIN")]
    public int Hfin { get; set; }
    [Required]
    [Column("MFIN")]
    public int Mfin { get; set; }
    [Required]
    [Column("MEDECIN_ID")]
    public int MedecinId { get; set; }
    [Required]
    [ForeignKey("MedecinId")]
    public virtual Medecin Medecin { get; set; }
    // les Rvs du créneau
    public ICollection<Rv> Rvs { get; set; }
    [ConcurrencyCheck]
    [Column("VERSIONING")]
    public int? Versioning { get; set; }

    // signature
    public override string ToString()
    {
      return String.Format("Creneau [{0},{1},{2},{3},{4}, {5},{6}]", Id, Hdebut, Mdebut, Hfin, Mfin, Medecin, Versioning);
    }
    // signature courte
    public string ShortIdentity()
    {
      return String.Format("Creneau [{0},{1},{2},{3},{4}, {5}, {6}]", Id, Hdebut, Mdebut, Hfin, Mfin, MedecinId, Versioning);
    }
  }

  // un rendez-vous
  [Table("RVS", Schema = "RDVMEDECINS-EF")]
  public class Rv
  {
    // data
    [Key]
    [Column("ID")]
    public int? Id { get; set; }
    [Required]
    [Column("JOUR")]
    public DateTime Jour { get; set; }
    [Column("CLIENT_ID")]
    public int ClientId { get; set; }
    [ForeignKey("ClientId")]
    [Required]
    public virtual Client Client { get; set; }
    [Column("CRENEAU_ID")]
    public int CreneauId { get; set; }
    [ForeignKey("CreneauId")]
    [Required]
    public virtual Creneau Creneau { get; set; }
    [ConcurrencyCheck]
    [Column("VERSIONING")]
    public int? Versioning { get; set; }

    // signature
    public override string ToString()
    {
      return String.Format("Rv [{0},{1},{2},{3},{4}]", Id, Jour, Client, Creneau, Versioning);
    }
    // signature courte
    public string ShortIdentity()
    {
      return String.Format("Rv [{0},{1},{2},{3},{4}]", Id, Jour, ClientId, CreneauId, Versioning);
    }
  }
}
