﻿using System;
using System.Collections.Generic;
using System.Web.UI.WebControls;
using RdvMedecins.Entites;
using Rdvmedecins.Web.Entites;

namespace Rdvmedecins.Web
{
    public partial class _Default : System.Web.UI.Page
    {
        // champs d'instance
        private DateTime dateJour;

        // initialisation page lors du GET initial
        protected void Page_Load(object sender, EventArgs e)
        {
            // traitement requête initiale
            if (!IsPostBack)
            {
                // y-a-t-il eu des erreurs d'initialisation ?
                if (Global.Erreur)
                {
                    // on prépare la liste des erreurs
                    List<string> erreurs = new List<string>();
                    erreurs.Add(Global.Msg);
                    RptErreurs.DataSource = erreurs;
                    RptErreurs.DataBind();
                    // affichage vue [erreurs]
                    Vues.ActiveViewIndex = 1;
                    return;
                }
                // pas d'erreurs d'initialisation
                // chargement des noms des médecins dans le combo des médecins
                foreach (Medecin medecin in Global.Medecins)
                {
                    DropDownListMedecins.Items.Add(new ListItem(string.Format("{0} {1} {2}", medecin.Titre, medecin.Prenom, medecin.Nom), medecin.Id.ToString()));
                }
                // sélection 1er médecin
                DropDownListMedecins.SelectedIndex = 0;
                // chargement des noms des clients dans le combo des clients
                foreach (Client client in Global.Clients)
                {
                    DropDownListClients.Items.Add(new ListItem(string.Format("{0} {1} {2}", client.Titre, client.Prenom, client.Nom), client.Id.ToString()));
                }
                // sélection 1er client
                DropDownListMedecins.SelectedIndex = 0;
                // affichage vue [saisie]
                Vues.ActiveViewIndex = 0;
            }
        }

        // vérification date de Rdv
        protected void CustomValidatorJour_ServerValidate(object source, ServerValidateEventArgs args)
        {
            // rien à vérifier si la page est déjà invalide
            if (!Page.IsValid) return;

            // on récupère le jour jj/mm/aaaa
            string jour = TextBoxJour.Text.Trim();
            // on récupère les éléments du jour
            string[] elements = jour.Split(new Char[] { '/' });
            // on crée une date avec
            try
            {
                dateJour = new DateTime(int.Parse(elements[2]), int.Parse(elements[1]), int.Parse(elements[0]));
                args.IsValid = true;
            }
            catch
            {
                args.IsValid = false;
            }
        }

        // affichage de l'agenda d'un médecin pour un jour donné
        protected void ButtonValider_Click(object sender, EventArgs e)
        {
            // données valides ?
            Page.Validate();
            // on retourne à la page si l'un des validateurs échoue
            if (!Page.IsValid) return;
            // on affiche la liste des Rv du médecin
            Medecin medecin = Global.Medecins[DropDownListMedecins.SelectedIndex];
            LabelRvMedecinJour.Text = string.Format("Rendez-vous de {0} le {1}", DropDownListMedecins.SelectedItem.ToString(), TextBoxJour.Text.Trim());
            // agenda du médecin le jour DateJour
            AgendaMedecinJour agenda = getAgendaMedecinJour(medecin, dateJour);
            // on le met dans la session de l'utilisateur
            Session["agenda"] = agenda;
            // association de la liste des créneaux de l'agenda au GridView
            GridViewRVMedecinJour.DataSource = agenda.Creneaux;
            GridViewRVMedecinJour.DataBind();
            // vue Agenda
            Vues.ActiveViewIndex = 2;
        }

        // agenda d'un médecin pour un jour donné
        private AgendaMedecinJour getAgendaMedecinJour(Medecin medecin, DateTime dateJour)
        {
            // il nous faut d'abord la liste des créneaux horaires du médecin
            List<Creneau> creneauxHoraires = Global.Dao.GetCreneauxMedecin((int)medecin.Id);
            // qu'on trie dans l'ordre des heures de début
            creneauxHoraires.Sort(new ComparerCreneau());
            // il nous faut également la liste des RV déjà pris pour ce médecin et le jour choisi
            List<Rv> rvPris = Global.Dao.GetRvMedecinJour((int)medecin.Id, dateJour);
            // on crée un dictionnaire à partir des Rv pris
            Dictionary<int, Rv> dicoRvPris = new Dictionary<int, Rv>();
            foreach (Rv rdv in rvPris)
            {
                dicoRvPris[(int)rdv.CreneauId] = rdv;
            }
            // on crée l'agenda du médecin pour le jour donné
            AgendaMedecinJour agenda = new AgendaMedecinJour();
            // le médecin
            agenda.UnMedecin = medecin;
            // le jour
            agenda.DateJour = dateJour;
            // remplissage des créneaux de réservation du médecin
            agenda.Creneaux = new List<CreneauMedecinJour>();
            for (int i = 0; i < creneauxHoraires.Count - 1; i++)
            {
                // ligne i de l'agenda
                agenda.Creneaux.Add(new CreneauMedecinJour());
                // l'id du créneau
                agenda.Creneaux[i].IdCreneau = (int)creneauxHoraires[i].Id;
                // le créneau horaire
                agenda.Creneaux[i].CreneauHoraire = string.Format("{0:00}h{1:00}-{2:00}h{3:00}", creneauxHoraires[i].Hdebut, creneauxHoraires[i].Mdebut, creneauxHoraires[i].Hfin, creneauxHoraires[i].Mfin);
                // y-a-t-il un RV pris pour ce créneau
                if (dicoRvPris.ContainsKey((int)creneauxHoraires[i].Id))
                {
                    // le RV
                    agenda.Creneaux[i].Rdv = dicoRvPris[(int)creneauxHoraires[i].Id];
                    // créneau réservé - on cherche le client dans la base
                    Client client = Global.Dao.Find<Client>(agenda.Creneaux[i].Rdv.ClientId);
                    // on l'inscrit dans l'agenda
                    agenda.Creneaux[i].Client = string.Format("{0} {1} {2}", client.Titre, client.Prenom, client.Nom);
                    // on peut supprimer ce RV
                    agenda.Creneaux[i].Commande = "Supprimer";
                }
                else
                {
                    // le créneau n'est pas encore réservé
                    agenda.Creneaux[i].Commande = "Réserver";
                    agenda.Creneaux[i].Client = "";
                }
            }
            // on rend le résultat
            return agenda;
        }


        // retour à la page d'accueil
        protected void ButtonAccueil_Click(object sender, EventArgs e)
        {
            // retour à la page d'accueil
            Vues.ActiveViewIndex = 0;

        }

        // commande sur une ligne du GridView des Rdv
        protected void GridViewRVMedecinJour_RowCommand(object sender, GridViewCommandEventArgs e)
        {
            // session valide ?
            if (Session.IsNewSession)
            {
                // retour à la page d'accueil
                Vues.ActiveViewIndex = 0;
                return;
            }
            // quelle est la ligne du GridView concernée ?
            int iCreneau = int.Parse(e.CommandArgument.ToString());
            // on récupère le type de la commande associée à cette ligne
            AgendaMedecinJour agenda = Session["agenda"] as AgendaMedecinJour;
            string commande = agenda.Creneaux[iCreneau].Commande;
            // exécution commande
            if (commande == "Réserver")
            {
                // affichage Infos du Rv
                string creneauHoraire = agenda.Creneaux[iCreneau].CreneauHoraire;
                string jour = agenda.DateJour.ToString("dd/MM/yyyy");
                Medecin medecin = agenda.UnMedecin;
                string nomMedecin = string.Format("{0} {1} {2}", medecin.Titre, medecin.Prenom, medecin.Nom);
                LabelIdRv.Text = string.Format("Rendez-vous : {0}, Jour : {1}, Médecin : {2}", creneauHoraire, jour, nomMedecin);
                // on met l'Id du créneau dans le ViewState de la page
                ViewState["idCreneau"] = agenda.Creneaux[iCreneau].IdCreneau;
                // affichage ViewChoixRvPourClient
                Vues.ActiveViewIndex = 3;
                return;
            }
            if (commande == "Supprimer")
            {
                try
                {
                    // suppression Rv
                    Global.Dao.SupprimerRv((int)agenda.Creneaux[iCreneau].Rdv.Id);
                }
                catch (Exception ex)
                {
                    // vue erreurs
                    List<string> erreurs = new List<string>();
                    erreurs.Add(ex.ToString());
                    RptErreurs.DataSource = erreurs;
                    RptErreurs.DataBind();
                    Vues.ActiveViewIndex = 1;
                    return;
                }
                // agenda du médecin le jour DateJour
                agenda = getAgendaMedecinJour(agenda.UnMedecin, agenda.DateJour);
                // on le remet dans la session de l'utilisateur
                Session["Agenda"] = agenda;
                // régénération du GridView
                GridViewRVMedecinJour.DataSource = agenda.Creneaux;
                GridViewRVMedecinJour.DataBind();
            }
        }

        // ajout d'un Rv
        protected void ButtonvaliderRv_Click(object sender, EventArgs e)
        {
            // session valide ?
            if (Session.IsNewSession)
            {
                // retour à la page d'accueil
                Vues.ActiveViewIndex = 0;
                return;
            }
            // on récupère l'agenda du médecin dans la session
            AgendaMedecinJour agenda = Session["agenda"] as AgendaMedecinJour;
            try
            {
                // on ajoute le RV
                Global.Dao.AjouterRv(agenda.DateJour, (int)ViewState["idCreneau"], int.Parse(DropDownListClients.SelectedValue));
            }
            catch (Exception ex)
            {
                // vue erreurs
                List<string> erreurs = new List<string>();
                erreurs.Add(ex.ToString());
                RptErreurs.DataSource = erreurs;
                RptErreurs.DataBind();
                Vues.ActiveViewIndex = 1;
                return;
            }
            // on régénère l'agenda du médecin le jour DateJour
            agenda = getAgendaMedecinJour(agenda.UnMedecin, agenda.DateJour);
            // on le remet dans la session de l'utilisateur
            Session["Agenda"] = agenda;
            // régénération du GridView
            GridViewRVMedecinJour.DataSource = agenda.Creneaux;
            GridViewRVMedecinJour.DataBind();
            // vue Agenda médecin
            Vues.ActiveViewIndex = 2;
        }

        // annulation d'une prise de Rdv
        protected void ButtonAnnulerRv_Click(object sender, EventArgs e)
        {
            // session valide ?
            if (Session.IsNewSession)
            {
                // retour à la page d'accueil
                Vues.ActiveViewIndex = 0;
                return;
            }
            // on récupère l'agenda du médecin dans la session
            AgendaMedecinJour agenda = Session["agenda"] as AgendaMedecinJour;
            // régénération du GridView
            GridViewRVMedecinJour.DataSource = agenda.Creneaux;
            GridViewRVMedecinJour.DataBind();
            // vue Agenda médecin
            Vues.ActiveViewIndex = 2;
        }
    }

    // classe de compraison de créneaux horaires
    public class ComparerCreneau : IComparer<Creneau>
    {
        public int Compare(Creneau c1, Creneau C2)
        {
            // on compare les heures et minutes du début du créneau
            int hdebut1 = c1.Hdebut;
            int hdebut2 = C2.Hdebut;
            int mdebut1 = c1.Mdebut;
            int mdebut2 = C2.Mdebut;

            if (hdebut1 < hdebut2) return -1;
            if (hdebut1 > hdebut2) return +1;
            if (mdebut1 < mdebut2) return -1;
            if (mdebut1 > mdebut2) return +1;
            return 0;
        }
    }
}
