﻿using System;
using System.Collections.Generic;
using RdvMedecins.Dao;
using RdvMedecins.Entites;
using RdvMedecins.Exceptions;
using Spring.Context.Support;

namespace RdvMedecins.Tests
{
  class Program
  {
    public static void Main()
    {
      IDao dao = null;
      try
      {
        // instanciation couche [dao] via Spring
        dao = ContextRegistry.GetContext().GetObject("rdvmedecinsDao") as IDao;
        // affichage clients
        List<Client> clients = dao.GetAllClients();
        DisplayClients("Liste des clients :", clients);
        // affichage médecins
        List<Medecin> medecins = dao.GetAllMedecins();
        DisplayMedecins("Liste des médecins :", medecins);
        // liste des créneaux horaires du médecin n° 1
        List<Creneau> creneaux = dao.GetCreneauxMedecin((int)medecins[0].Id);
        DisplayCreneaux(string.Format("Liste des créneaux horaires du médecin {0}", medecins[0]), creneaux);
        // liste des Rv d'un médecin pour un jour donné
        DisplayRvs(string.Format("Liste des RV du médecin {0}, le 23/11/2013 :", medecins[0]), dao.GetRvMedecinJour((int)medecins[0].Id, new DateTime(2013, 11, 23)));
        // ajouter un RV au médecin n°1 dans créneau n° 1
        Console.WriteLine(string.Format("Ajout d'un RV au médecin {0} avec client {1} le 23/11/2013", medecins[0], clients[0]));
        int idRv1 = dao.AjouterRv(new DateTime(2013, 11, 23), (int)creneaux[0].Id, (int)clients[0].Id);
        Console.WriteLine("Rdv ajouté");
        DisplayRvs(string.Format("Liste des RV du médecin {0}, le 23/11/2013 :", medecins[0]), dao.GetRvMedecinJour((int)medecins[0].Id, new DateTime(2013, 11, 23)));
        // ajouter un Rv dans un créneau déjà occupé - doit provoquer une exception
        int idRv2;
        Console.WriteLine("Ajout d'un RV dans un créneau déjà occupé");
        try
        {
          idRv2 = dao.AjouterRv(new DateTime(2013, 11, 23), (int)creneaux[0].Id, (int)clients[0].Id);
          Console.WriteLine("Rdv ajouté");
          DisplayRvs(string.Format("Liste des RV du médecin {0}, le 23/11/2013 :", medecins[0]), dao.GetRvMedecinJour((int)medecins[0].Id, new DateTime(2013, 11, 23)));
        }
        catch (RdvMedecinsException ex)
        {
          Console.WriteLine(string.Format("L'erreur suivante s'est produite : {0}", ex));
        }
        // supprimer un Rv
        Console.WriteLine(string.Format("Suppression du RV n° {0}", idRv1));
        dao.SupprimerRv(idRv1);
        DisplayRvs(string.Format("Liste des RV du médecin {0}, le 23/11/2013 :", medecins[0]), dao.GetRvMedecinJour((int)medecins[0].Id, new DateTime(2013, 11, 23)));
        // recherche par clé primaire
        Client client = dao.Find<Client>((int)clients[0].Id);
        Console.WriteLine(client.ShortIdentity());
      }
      catch (Exception ex)
      {
        Console.WriteLine(string.Format("L'erreur suivante s'est produite : {0}", ex));
      }
      //pause 
      Console.ReadLine();
    }

    // méthodes utilitaires - affiche des listes
    public static void DisplayClients(string Message, List<Client> clients)
    {
      Console.WriteLine(Message);
      foreach (Client c in clients)
      {
        Console.WriteLine(c.ShortIdentity());
      }
    }
    public static void DisplayMedecins(string Message, List<Medecin> medecins)
    {
      Console.WriteLine(Message);
      foreach (Medecin m in medecins)
      {
        Console.WriteLine(m.ShortIdentity());
      }
    }
    public static void DisplayCreneaux(string Message, List<Creneau> creneaux)
    {
      Console.WriteLine(Message);
      foreach (Creneau c in creneaux)
      {
        Console.WriteLine(c.ShortIdentity());
      }
    }
    public static void DisplayRvs(string Message, List<Rv> rvs)
    {
      Console.WriteLine(Message);
      foreach (Rv rv in rvs)
      {
        Console.WriteLine(rv.ShortIdentity());
      }
    }
  }

}
