﻿/* SQL Manager Lite for InterBase and Firebird 5.2.2.5                                         */
/* ------------------------------------------------------------------------------------------- */
/* Host     : localhost                                                                        */
/* Database : D:\data\istia-1213\c#\dvp\Entity Framework\databases\firebird\RDVMEDECINS-EF.GDB */


/* Structure for the `CLIENTS` table :  */

CREATE TABLE CLIENTS (
  ID INTEGER NOT NULL,
  TITRE VARCHAR(30) NOT NULL,
  PRENOM VARCHAR(30) NOT NULL,
  NOM VARCHAR(30) NOT NULL,
  VERSIONING BIGINT NOT NULL);


ALTER TABLE CLIENTS ADD PRIMARY KEY (ID);

/* Definition for the `CLIENTS_ID_GEN` generator :  */

CREATE GENERATOR CLIENTS_ID_GEN;

SET GENERATOR CLIENTS_ID_GEN TO 20;

/* Definition for the `BI_CLIENTS_ID` trigger :  */

SET TERM ^ ;

CREATE TRIGGER BI_CLIENTS_ID FOR CLIENTS
ACTIVE BEFORE INSERT
POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
      NEW.ID = GEN_ID(CLIENTS_ID_GEN, 1);
END^

SET TERM ; ^

/* Structure for the `MEDECINS` table :  */

CREATE TABLE MEDECINS (
  ID INTEGER NOT NULL,
  TITRE VARCHAR(5) NOT NULL,
  PRENOM VARCHAR(30) NOT NULL,
  NOM VARCHAR(30) NOT NULL,
  VERSIONING BIGINT NOT NULL);


ALTER TABLE MEDECINS ADD PRIMARY KEY (ID);

/* Structure for the `CRENEAUX` table :  */

CREATE TABLE CRENEAUX (
  ID INTEGER NOT NULL,
  HDEBUT SMALLINT NOT NULL,
  MDEBUT SMALLINT NOT NULL,
  HFIN SMALLINT NOT NULL,
  MFIN SMALLINT NOT NULL,
  MEDECIN_ID INTEGER NOT NULL,
  VERSIONING BIGINT NOT NULL);


ALTER TABLE CRENEAUX ADD PRIMARY KEY (ID);

ALTER TABLE CRENEAUX ADD CONSTRAINT FK_CRENEAUX FOREIGN KEY (MEDECIN_ID) REFERENCES MEDECINS(ID) ON DELETE CASCADE;

/* Definition for the `CRENEAUX_ID_GEN` generator :  */

CREATE GENERATOR CRENEAUX_ID_GEN;

SET GENERATOR CRENEAUX_ID_GEN TO 145;

/* Definition for the `BI_CRENEAUX_ID` trigger :  */

SET TERM ^ ;

CREATE TRIGGER BI_CRENEAUX_ID FOR CRENEAUX
ACTIVE BEFORE INSERT
POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
      NEW.ID = GEN_ID(CRENEAUX_ID_GEN, 1);
END^

SET TERM ; ^

/* Definition for the `MEDECINS_ID_GEN` generator :  */

CREATE GENERATOR MEDECINS_ID_GEN;

SET GENERATOR MEDECINS_ID_GEN TO 17;

/* Definition for the `BI_MEDECINS_ID` trigger :  */

SET TERM ^ ;

CREATE TRIGGER BI_MEDECINS_ID FOR MEDECINS
ACTIVE BEFORE INSERT
POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
      NEW.ID = GEN_ID(MEDECINS_ID_GEN, 1);
END^

SET TERM ; ^

/* Structure for the `RVS` table :  */

CREATE TABLE RVS (
  ID INTEGER NOT NULL,
  JOUR DATE NOT NULL,
  CRENEAU_ID INTEGER NOT NULL,
  CLIENT_ID INTEGER NOT NULL,
  VERSIONING BIGINT NOT NULL);


ALTER TABLE RVS ADD PRIMARY KEY (ID);

ALTER TABLE RVS ADD CONSTRAINT FK_RVS FOREIGN KEY (CRENEAU_ID) REFERENCES CRENEAUX(ID) ON DELETE CASCADE;

ALTER TABLE RVS ADD CONSTRAINT FK_RVS1 FOREIGN KEY (CLIENT_ID) REFERENCES CLIENTS(ID) ON DELETE CASCADE;

ALTER TABLE RVS ADD CONSTRAINT UQ_RVS UNIQUE (CRENEAU_ID,JOUR);

/* Definition for the `RVS_ID_GEN` generator :  */

CREATE GENERATOR RVS_ID_GEN;

SET GENERATOR RVS_ID_GEN TO 6;

/* Definition for the `BI_RVS_ID` trigger :  */

SET TERM ^ ;

CREATE TRIGGER BI_RVS_ID FOR RVS
ACTIVE BEFORE INSERT
POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
      NEW.ID = GEN_ID(RVS_ID_GEN, 1);
END^

SET TERM ; ^

/* Definition for the `VERSIONS_GEN` generator :  */

CREATE GENERATOR VERSIONS_GEN;

SET GENERATOR VERSIONS_GEN TO 230;

/* Definition for the `CLIENTS_VERSION_TRIGGER` trigger :  */

SET TERM ^ ;

CREATE TRIGGER CLIENTS_VERSION_TRIGGER FOR CLIENTS
ACTIVE BEFORE INSERT OR UPDATE
POSITION 1
AS
BEGIN
  NEW."VERSIONING" = GEN_ID(VERSIONS_GEN,1);
END^

SET TERM ; ^

/* Definition for the `CRENEAUX_VERSION_TRG` trigger :  */

SET TERM ^ ;

CREATE TRIGGER CRENEAUX_VERSION_TRG FOR CRENEAUX
ACTIVE BEFORE INSERT OR UPDATE
POSITION 0
AS
BEGIN
   NEW."VERSIONING" = GEN_ID(VERSIONS_GEN,1);
END^

SET TERM ; ^

/* Definition for the `MEDECINS_VERSION_TRG` trigger :  */

SET TERM ^ ;

CREATE TRIGGER MEDECINS_VERSION_TRG FOR MEDECINS
ACTIVE BEFORE INSERT OR UPDATE
POSITION 0
AS
BEGIN
   NEW."VERSIONING" = GEN_ID(VERSIONS_GEN,1);
END^

SET TERM ; ^

/* Definition for the `RVS_VERSION_TRIGGER` trigger :  */

SET TERM ^ ;

CREATE TRIGGER RVS_VERSION_TRIGGER FOR RVS
ACTIVE BEFORE INSERT OR UPDATE
POSITION 1
AS
BEGIN
  NEW."VERSIONING" = GEN_ID(VERSIONS_GEN,1);
END^

SET TERM ; ^

/* Data for the `CLIENTS` table  (Records 1 - 4) */

INSERT INTO CLIENTS
VALUES (17, 'Mr', 'Jules', 'Martin', 186);

INSERT INTO CLIENTS
VALUES (18, 'Mme', 'Christine', 'German', 187);

INSERT INTO CLIENTS
VALUES (19, 'Mr', 'Jules', 'Jacquard', 188);

INSERT INTO CLIENTS
VALUES (20, 'Melle', 'Brigitte', 'Bistrou', 189);

COMMIT WORK;

/* Data for the `MEDECINS` table  (Records 1 - 4) */

INSERT INTO MEDECINS
VALUES (14, 'Mme', 'Marie', 'Pelissier', 190);

INSERT INTO MEDECINS
VALUES (15, 'Mr', 'Jacques', 'Bromard', 215);

INSERT INTO MEDECINS
VALUES (16, 'Mr', 'Philippe', 'Jandot', 228);

INSERT INTO MEDECINS
VALUES (17, 'Melle', 'Justine', 'Jacquemot', 229);

COMMIT WORK;

/* Data for the `CRENEAUX` table  (Records 1 - 36) */

INSERT INTO CRENEAUX
VALUES (110, 8, 0, 8, 20, 14, 191);

INSERT INTO CRENEAUX
VALUES (111, 8, 20, 8, 40, 14, 192);

INSERT INTO CRENEAUX
VALUES (112, 8, 40, 9, 0, 14, 193);

INSERT INTO CRENEAUX
VALUES (113, 9, 0, 9, 20, 14, 194);

INSERT INTO CRENEAUX
VALUES (114, 9, 20, 9, 40, 14, 195);

INSERT INTO CRENEAUX
VALUES (115, 9, 40, 10, 0, 14, 196);

INSERT INTO CRENEAUX
VALUES (116, 10, 0, 10, 20, 14, 197);

INSERT INTO CRENEAUX
VALUES (117, 10, 20, 10, 40, 14, 198);

INSERT INTO CRENEAUX
VALUES (118, 10, 40, 11, 0, 14, 199);

INSERT INTO CRENEAUX
VALUES (119, 11, 0, 11, 20, 14, 200);

INSERT INTO CRENEAUX
VALUES (120, 11, 20, 11, 40, 14, 201);

INSERT INTO CRENEAUX
VALUES (121, 11, 40, 12, 0, 14, 202);

INSERT INTO CRENEAUX
VALUES (122, 14, 0, 14, 20, 14, 203);

INSERT INTO CRENEAUX
VALUES (123, 14, 20, 14, 40, 14, 204);

INSERT INTO CRENEAUX
VALUES (124, 14, 40, 15, 0, 14, 205);

INSERT INTO CRENEAUX
VALUES (125, 15, 0, 15, 20, 14, 206);

INSERT INTO CRENEAUX
VALUES (126, 15, 20, 15, 40, 14, 207);

INSERT INTO CRENEAUX
VALUES (127, 15, 40, 16, 0, 14, 208);

INSERT INTO CRENEAUX
VALUES (128, 16, 0, 16, 20, 14, 209);

INSERT INTO CRENEAUX
VALUES (129, 16, 20, 16, 40, 14, 210);

INSERT INTO CRENEAUX
VALUES (130, 16, 40, 17, 0, 14, 211);

INSERT INTO CRENEAUX
VALUES (131, 17, 0, 17, 20, 14, 212);

INSERT INTO CRENEAUX
VALUES (132, 17, 20, 17, 40, 14, 213);

INSERT INTO CRENEAUX
VALUES (133, 17, 40, 18, 0, 14, 214);

INSERT INTO CRENEAUX
VALUES (134, 8, 0, 8, 20, 15, 216);

INSERT INTO CRENEAUX
VALUES (135, 8, 20, 8, 40, 15, 217);

INSERT INTO CRENEAUX
VALUES (136, 8, 40, 9, 0, 15, 218);

INSERT INTO CRENEAUX
VALUES (137, 9, 0, 9, 20, 15, 219);

INSERT INTO CRENEAUX
VALUES (138, 9, 20, 9, 40, 15, 220);

INSERT INTO CRENEAUX
VALUES (139, 9, 40, 10, 0, 15, 221);

INSERT INTO CRENEAUX
VALUES (140, 10, 0, 10, 20, 15, 222);

INSERT INTO CRENEAUX
VALUES (141, 10, 20, 10, 40, 15, 223);

INSERT INTO CRENEAUX
VALUES (142, 10, 40, 11, 0, 15, 224);

INSERT INTO CRENEAUX
VALUES (143, 11, 0, 11, 20, 15, 225);

INSERT INTO CRENEAUX
VALUES (144, 11, 20, 11, 40, 15, 226);

INSERT INTO CRENEAUX
VALUES (145, 11, 40, 12, 0, 15, 227);

COMMIT WORK;

/* Data for the `RVS` table  (Records 1 - 1) */

INSERT INTO RVS
VALUES (6, '2012-10-08', 110, 17, 230);

COMMIT WORK;

/* Privileges for the `CLIENTS` :  */


GRANT SELECT, INSERT, DELETE, REFERENCES, UPDATE ON CLIENTS TO SYSDBA WITH GRANT OPTION;


/* Privileges for the `CRENEAUX` :  */


GRANT SELECT, INSERT, DELETE, REFERENCES, UPDATE ON CRENEAUX TO SYSDBA WITH GRANT OPTION;


/* Privileges for the `MEDECINS` :  */


GRANT SELECT, INSERT, DELETE, REFERENCES, UPDATE ON MEDECINS TO SYSDBA WITH GRANT OPTION;


/* Privileges for the `RVS` :  */


GRANT SELECT, INSERT, DELETE, REFERENCES, UPDATE ON RVS TO SYSDBA WITH GRANT OPTION;

