﻿/* SQL Manager Lite for InterBase and Firebird 5.2.2.5                                         */
/* ------------------------------------------------------------------------------------------- */
/* Host     : localhost                                                                        */
/* Database : D:\data\istia-1213\c#\dvp\Entity Framework\databases\firebird\RDVMEDECINS-EF.GDB */


/* Structure for the `CLIENTS` table :  */

CREATE TABLE CLIENTS (
  ID INTEGER NOT NULL,
  TITRE VARCHAR(30) NOT NULL,
  PRENOM VARCHAR(30) NOT NULL,
  NOM VARCHAR(30) NOT NULL,
  VERSIONING BIGINT NOT NULL);


ALTER TABLE CLIENTS ADD PRIMARY KEY (ID);

/* Definition for the `CLIENTS_ID_GEN` generator :  */

CREATE GENERATOR CLIENTS_ID_GEN;

SET GENERATOR CLIENTS_ID_GEN TO 12;

/* Definition for the `BI_CLIENTS_ID` trigger :  */

SET TERM ^ ;

CREATE TRIGGER BI_CLIENTS_ID FOR CLIENTS
ACTIVE BEFORE INSERT
POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
      NEW.ID = GEN_ID(CLIENTS_ID_GEN, 1);
END^

SET TERM ; ^

/* Structure for the `MEDECINS` table :  */

CREATE TABLE MEDECINS (
  ID INTEGER NOT NULL,
  TITRE VARCHAR(5) NOT NULL,
  PRENOM VARCHAR(30) NOT NULL,
  NOM VARCHAR(30) NOT NULL,
  VERSIONING BIGINT NOT NULL);


ALTER TABLE MEDECINS ADD PRIMARY KEY (ID);

/* Structure for the `CRENEAUX` table :  */

CREATE TABLE CRENEAUX (
  ID INTEGER NOT NULL,
  HDEBUT SMALLINT NOT NULL,
  MDEBUT SMALLINT NOT NULL,
  HFIN SMALLINT NOT NULL,
  MFIN SMALLINT NOT NULL,
  MEDECIN_ID INTEGER NOT NULL,
  VERSIONING BIGINT NOT NULL);


ALTER TABLE CRENEAUX ADD PRIMARY KEY (ID);

ALTER TABLE CRENEAUX ADD CONSTRAINT FK_CRENEAUX FOREIGN KEY (MEDECIN_ID) REFERENCES MEDECINS(ID) ON DELETE CASCADE;

/* Definition for the `CRENEAUX_ID_GEN` generator :  */

CREATE GENERATOR CRENEAUX_ID_GEN;

SET GENERATOR CRENEAUX_ID_GEN TO 73;

/* Definition for the `BI_CRENEAUX_ID` trigger :  */

SET TERM ^ ;

CREATE TRIGGER BI_CRENEAUX_ID FOR CRENEAUX
ACTIVE BEFORE INSERT
POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
      NEW.ID = GEN_ID(CRENEAUX_ID_GEN, 1);
END^

SET TERM ; ^

/* Definition for the `MEDECINS_ID_GEN` generator :  */

CREATE GENERATOR MEDECINS_ID_GEN;

SET GENERATOR MEDECINS_ID_GEN TO 9;

/* Definition for the `BI_MEDECINS_ID` trigger :  */

SET TERM ^ ;

CREATE TRIGGER BI_MEDECINS_ID FOR MEDECINS
ACTIVE BEFORE INSERT
POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
      NEW.ID = GEN_ID(MEDECINS_ID_GEN, 1);
END^

SET TERM ; ^

/* Structure for the `RVS` table :  */

CREATE TABLE RVS (
  ID INTEGER NOT NULL,
  JOUR DATE NOT NULL,
  CRENEAU_ID INTEGER NOT NULL,
  CLIENT_ID INTEGER NOT NULL,
  VERSIONING BIGINT NOT NULL);


ALTER TABLE RVS ADD PRIMARY KEY (ID);

ALTER TABLE RVS ADD CONSTRAINT FK_RVS FOREIGN KEY (CRENEAU_ID) REFERENCES CRENEAUX(ID) ON DELETE CASCADE;

ALTER TABLE RVS ADD CONSTRAINT FK_RVS1 FOREIGN KEY (CLIENT_ID) REFERENCES CLIENTS(ID) ON DELETE CASCADE;

ALTER TABLE RVS ADD CONSTRAINT UQ_RVS UNIQUE (CRENEAU_ID,JOUR);

/* Definition for the `RVS_ID_GEN` generator :  */

CREATE GENERATOR RVS_ID_GEN;

SET GENERATOR RVS_ID_GEN TO 4;

/* Definition for the `BI_RVS_ID` trigger :  */

SET TERM ^ ;

CREATE TRIGGER BI_RVS_ID FOR RVS
ACTIVE BEFORE INSERT
POSITION 0
AS
BEGIN
  IF (NEW.ID IS NULL) THEN
      NEW.ID = GEN_ID(RVS_ID_GEN, 1);
END^

SET TERM ; ^

/* Definition for the `VERSIONS_GEN` generator :  */

CREATE GENERATOR VERSIONS_GEN;

SET GENERATOR VERSIONS_GEN TO 140;

/* Definition for the `CLIENTS_VERSION_TRIGGER` trigger :  */

SET TERM ^ ;

CREATE TRIGGER CLIENTS_VERSION_TRIGGER FOR CLIENTS
ACTIVE BEFORE INSERT OR UPDATE
POSITION 1
AS
BEGIN
  NEW."VERSIONING" = GEN_ID(VERSIONS_GEN,1);
END^

SET TERM ; ^

/* Definition for the `CRENEAUX_VERSION_TRG` trigger :  */

SET TERM ^ ;

CREATE TRIGGER CRENEAUX_VERSION_TRG FOR CRENEAUX
ACTIVE BEFORE INSERT OR UPDATE
POSITION 0
AS
BEGIN
   NEW."VERSIONING" = GEN_ID(VERSIONS_GEN,1);
END^

SET TERM ; ^

/* Definition for the `MEDECINS_VERSION_TRG` trigger :  */

SET TERM ^ ;

CREATE TRIGGER MEDECINS_VERSION_TRG FOR MEDECINS
ACTIVE BEFORE INSERT OR UPDATE
POSITION 0
AS
BEGIN
   NEW."VERSIONING" = GEN_ID(VERSIONS_GEN,1);
END^

SET TERM ; ^

/* Definition for the `RVS_VERSION_TRIGGER` trigger :  */

SET TERM ^ ;

CREATE TRIGGER RVS_VERSION_TRIGGER FOR RVS
ACTIVE BEFORE INSERT OR UPDATE
POSITION 1
AS
BEGIN
  NEW."VERSIONING" = GEN_ID(VERSIONS_GEN,1);
END^

SET TERM ; ^

/* Data for the `CLIENTS` table  (Records 1 - 4) */

INSERT INTO CLIENTS
VALUES (9, 'Mr', 'Jules', 'Martin', 97);

INSERT INTO CLIENTS
VALUES (10, 'Mme', 'Christine', 'German', 98);

INSERT INTO CLIENTS
VALUES (11, 'Mr', 'Jules', 'Jacquard', 99);

INSERT INTO CLIENTS
VALUES (12, 'Melle', 'Brigitte', 'Bistrou', 100);

COMMIT WORK;

/* Data for the `MEDECINS` table  (Records 1 - 4) */

INSERT INTO MEDECINS
VALUES (6, 'Mme', 'Marie', 'Pelissier', 137);

INSERT INTO MEDECINS
VALUES (7, 'Mr', 'Jacques', 'Bromard', 138);

INSERT INTO MEDECINS
VALUES (8, 'Mr', 'Philippe', 'Jandot', 139);

INSERT INTO MEDECINS
VALUES (9, 'Melle', 'Justine', 'Jacquemot', 140);

COMMIT WORK;

/* Data for the `CRENEAUX` table  (Records 1 - 36) */

INSERT INTO CRENEAUX
VALUES (38, 8, 0, 8, 20, 6, 101);

INSERT INTO CRENEAUX
VALUES (39, 8, 20, 8, 40, 6, 102);

INSERT INTO CRENEAUX
VALUES (40, 8, 40, 9, 0, 6, 103);

INSERT INTO CRENEAUX
VALUES (41, 9, 0, 9, 20, 6, 104);

INSERT INTO CRENEAUX
VALUES (42, 9, 20, 9, 40, 6, 105);

INSERT INTO CRENEAUX
VALUES (43, 9, 40, 10, 0, 6, 106);

INSERT INTO CRENEAUX
VALUES (44, 10, 0, 10, 20, 6, 107);

INSERT INTO CRENEAUX
VALUES (45, 10, 20, 10, 40, 6, 108);

INSERT INTO CRENEAUX
VALUES (46, 10, 40, 11, 0, 6, 109);

INSERT INTO CRENEAUX
VALUES (47, 11, 0, 11, 20, 6, 110);

INSERT INTO CRENEAUX
VALUES (48, 11, 20, 11, 40, 6, 111);

INSERT INTO CRENEAUX
VALUES (49, 11, 40, 12, 0, 6, 112);

INSERT INTO CRENEAUX
VALUES (50, 14, 0, 14, 20, 6, 113);

INSERT INTO CRENEAUX
VALUES (51, 14, 20, 14, 40, 6, 114);

INSERT INTO CRENEAUX
VALUES (52, 14, 40, 15, 0, 6, 115);

INSERT INTO CRENEAUX
VALUES (53, 15, 0, 15, 20, 6, 116);

INSERT INTO CRENEAUX
VALUES (54, 15, 20, 15, 40, 6, 117);

INSERT INTO CRENEAUX
VALUES (55, 15, 40, 16, 0, 6, 118);

INSERT INTO CRENEAUX
VALUES (56, 16, 0, 16, 20, 6, 119);

INSERT INTO CRENEAUX
VALUES (57, 16, 20, 16, 40, 6, 120);

INSERT INTO CRENEAUX
VALUES (58, 16, 40, 17, 0, 6, 121);

INSERT INTO CRENEAUX
VALUES (59, 17, 0, 17, 20, 6, 122);

INSERT INTO CRENEAUX
VALUES (60, 17, 20, 17, 40, 6, 123);

INSERT INTO CRENEAUX
VALUES (61, 17, 40, 18, 0, 6, 124);

INSERT INTO CRENEAUX
VALUES (62, 8, 0, 8, 20, 7, 125);

INSERT INTO CRENEAUX
VALUES (63, 8, 20, 8, 40, 7, 126);

INSERT INTO CRENEAUX
VALUES (64, 8, 40, 9, 0, 7, 127);

INSERT INTO CRENEAUX
VALUES (65, 9, 0, 9, 20, 7, 128);

INSERT INTO CRENEAUX
VALUES (66, 9, 20, 9, 40, 7, 129);

INSERT INTO CRENEAUX
VALUES (67, 9, 40, 10, 0, 7, 130);

INSERT INTO CRENEAUX
VALUES (68, 10, 0, 10, 20, 7, 131);

INSERT INTO CRENEAUX
VALUES (69, 10, 20, 10, 40, 7, 132);

INSERT INTO CRENEAUX
VALUES (70, 10, 40, 11, 0, 7, 133);

INSERT INTO CRENEAUX
VALUES (71, 11, 0, 11, 20, 7, 134);

INSERT INTO CRENEAUX
VALUES (72, 11, 20, 11, 40, 7, 135);

INSERT INTO CRENEAUX
VALUES (73, 11, 40, 12, 0, 7, 136);

COMMIT WORK;

/* Data for the `RVS` table  (Records 1 - 1) */

INSERT INTO RVS
VALUES (4, '2012-10-08', 38, 9, 0);

COMMIT WORK;

/* Privileges for the `CLIENTS` :  */


GRANT SELECT, INSERT, DELETE, REFERENCES, UPDATE ON CLIENTS TO SYSDBA WITH GRANT OPTION;


/* Privileges for the `CRENEAUX` :  */


GRANT SELECT, INSERT, DELETE, REFERENCES, UPDATE ON CRENEAUX TO SYSDBA WITH GRANT OPTION;


/* Privileges for the `MEDECINS` :  */


GRANT SELECT, INSERT, DELETE, REFERENCES, UPDATE ON MEDECINS TO SYSDBA WITH GRANT OPTION;


/* Privileges for the `RVS` :  */


GRANT SELECT, INSERT, DELETE, REFERENCES, UPDATE ON RVS TO SYSDBA WITH GRANT OPTION;

